==> hyfi-0.2.4.tar.gz: hyfi-0.2.4/README.md <==
# HyFI: Hydra Fast Interface

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![jupyter-book-image]][jupyter book]
[![license-image]][license-url]

<!-- Links: -->
[pypi-image]: https://badge.fury.io/py/hyfi.svg
[pypi-url]: https://badge.fury.io/py/hyfi
[license-image]: https://img.shields.io/github/license/entelecheia/hyfi
[license-url]: https://github.com/entelecheia/hyfi/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/hyfi?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/hyfi
[release-url]: https://github.com/entelecheia/hyfi/releases
[conventional-commits-image]: https://img.shields.io/badge/Conventional%20Commits-1.0.0-%23FE5196?logo=conventionalcommits&logoColor=white
[conventional commits]: https://conventionalcommits.org
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg
[jupyter book]: https://hyfi.entelecheia.cc

[repo-url]: https://github.com/entelecheia/hyfi
[pypi-url]: https://pypi.org/project/hyfi
[docs-url]: https://hyfi.entelecheia.cc
[changelog]: https://github.com/entelecheia/hyfi/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/hyfi/blob/main/CONTRIBUTING.md
<!-- Links: -->

Hydra Fast Interface (Hydra and Pydantic based interface framework)

- Documentation: [https://hyfi.entelecheia.cc][docs-url]
- GitHub: [https://github.com/entelecheia/hyfi][repo-url]
- PyPI: [https://pypi.org/project/hyfi][pypi-url]

HyFI is a framework for building interfaces for Python applications. It is based on [Hydra] and [Pydantic] and provides a set of tools to build interfaces for Python applications.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].

==> hyfi-1.3.1.tar.gz: hyfi-1.3.1/README.md <==
# HyFI: Hydra Fast Interface

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]


<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/hyfi/branch/main/graph/badge.svg?token=HCYTYW1WVF
[codecov-url]: https://codecov.io/gh/entelecheia/hyfi
[pypi-image]: https://img.shields.io/pypi/v/hyfi
[license-image]: https://img.shields.io/github/license/entelecheia/hyfi
[license-url]: https://github.com/entelecheia/hyfi/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/hyfi?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/hyfi
[release-url]: https://github.com/entelecheia/hyfi/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/hyfi
[pypi-url]: https://pypi.org/project/hyfi
[docs-url]: https://hyfi.entelecheia.ai
[changelog]: https://github.com/entelecheia/hyfi/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/hyfi/blob/main/CONTRIBUTING.md
<!-- Links: -->

Hydra Fast Interface (Hydra and Pydantic based interface framework)

- Documentation: [https://hyfi.entelecheia.ai][docs-url]
- GitHub: [https://github.com/entelecheia/hyfi][repo-url]
- PyPI: [https://pypi.org/project/hyfi][pypi-url]

HyFI is a framework for building interfaces for Python applications. It is based on [Hydra](https://hydra.cc) and [Pydantic](https://docs.pydantic.dev/latest/) and provides a set of tools to build interfaces for Python applications.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [MIT License][license-url].
